@@ -328,7 +328,9 @@ class DocDBClient(BaseClient):
         PreferredMaintenanceWindow: str = ...,
         AutoMinorVersionUpgrade: bool = ...,
         Tags: Sequence["TagTypeDef"] = ...,
-        PromotionTier: int = ...
+        PromotionTier: int = ...,
+        EnablePerformanceInsights: bool = ...,
+        PerformanceInsightsKMSKeyId: str = ...
     ) -> CreateDBInstanceResultTypeDef:
         """
         Creates a new instance.
@@ -383,7 +385,7 @@ class DocDBClient(BaseClient):
     ) -> CreateGlobalClusterResultTypeDef:
         """
         Creates an Amazon DocumentDB global cluster that can span multiple multiple
-        Regions.
+        Amazon Web Services Regions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.create_global_cluster)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#create_global_cluster)
@@ -467,7 +469,7 @@ class DocDBClient(BaseClient):
     ) -> CertificateMessageTypeDef:
         """
         Returns a list of certificate authority (CA) certificates provided by Amazon
-        DocumentDB for this account.
+        DocumentDB for this Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_certificates)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_certificates)
@@ -806,7 +808,9 @@ class DocDBClient(BaseClient):
         AutoMinorVersionUpgrade: bool = ...,
         NewDBInstanceIdentifier: str = ...,
         CACertificateIdentifier: str = ...,
-        PromotionTier: int = ...
+        PromotionTier: int = ...,
+        EnablePerformanceInsights: bool = ...,
+        PerformanceInsightsKMSKeyId: str = ...
     ) -> ModifyDBInstanceResultTypeDef:
         """
         Modifies settings for an instance.
